==> eam-wshub-proxyclient-11.4-11-sources.jar: net/datastream/schemas/mp_fields/BOOKEDHOURSID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour BOOKEDHOURSID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="BOOKEDHOURSID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="BOOKEDHOURSCODE" type="{http://schemas.datastream.net/MP_fields}CODE30_Type"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "BOOKEDHOURSID_Type", propOrder = {
    "bookedhourscode"
})
public class BOOKEDHOURSID_Type {

    @XmlElement(name = "BOOKEDHOURSCODE", required = true)
    protected String bookedhourscode;

    /**
     * Obtient la valeur de la propriété bookedhourscode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getBOOKEDHOURSCODE() {
        return bookedhourscode;
    }

    /**
     * Définit la valeur de la propriété bookedhourscode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setBOOKEDHOURSCODE(String value) {
        this.bookedhourscode = value;
    }

}

==> eam-wshub-proxyclient-12.1-0-sources.jar: net/datastream/schemas/mp_fields/BOOKEDHOURSID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for BOOKEDHOURSID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="BOOKEDHOURSID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="BOOKEDHOURSCODE" type="{http://schemas.datastream.net/MP_fields}CODE30_Type"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "BOOKEDHOURSID_Type", propOrder = {
    "bookedhourscode"
})
public class BOOKEDHOURSID_Type {

    @XmlElement(name = "BOOKEDHOURSCODE", required = true)
    protected String bookedhourscode;

    /**
     * Gets the value of the bookedhourscode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getBOOKEDHOURSCODE() {
        return bookedhourscode;
    }

    /**
     * Sets the value of the bookedhourscode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setBOOKEDHOURSCODE(String value) {
        this.bookedhourscode = value;
    }

}
